django-coop
===============================================
An work-in-progress to build collaborative organizations management server.
Manages organizations, contact informations, members, relations between organizations, places, impact areas, tags, categories, exchanges (products, services, partnerships).
It may feed its data through a D2R server `mapping <https://github.com/quinode/coop-d2r-mapping>`_ to a RDF aggregation platform that acts as a hub for different networks.
The target is the Social and Solidarity Economy Sector.

'Installation intructions are (in french...)  on the wiki <http://redmine.django.coop/projects/django-coop/wiki/Installation>`_.

License
=======
django-coop uses the same license as Django (BSD).
django-coop development was funded by `CREDIS <http://credis.org/>`_, FSE (European Social Fund) and `<http://www.auvergne.fr/> Conseil Regional d'Auvergne`_.
